searchData={"items":[{"type":"module","title":"BinaryExtendedGcd","doc":"A fast implementation of the binary extended GCD algorithm.\n\nThis module provides an efficient implementation of the extended greatest common divisor\n(GCD) algorithm using the binary GCD method. The binary GCD algorithm is particularly\nefficient for large integers as it eliminates the need for expensive division operations\nby using only bit shifts and additions.","ref":"BinaryExtendedGcd.html"},{"type":"module","title":"Extended GCD - BinaryExtendedGcd","doc":"The extended GCD not only computes the greatest common divisor of two integers `a` and `b`,\nbut also finds Bézout coefficients $x$ and $y$ such that:\n\n$$gcd(a, b) = ax + by$$\n\nThis is useful in many cryptographic applications, modular arithmetic, and solving\nlinear Diophantine equations.","ref":"BinaryExtendedGcd.html#module-extended-gcd"},{"type":"module","title":"Algorithm - BinaryExtendedGcd","doc":"The binary extended GCD algorithm works by:\n1. Extracting common factors of 2 from both numbers\n2. Using bit operations to handle even/odd cases efficiently\n3. Maintaining Bézout coefficients throughout the computation\n4. Restoring the common factors at the end","ref":"BinaryExtendedGcd.html#module-algorithm"},{"type":"module","title":"Performance - BinaryExtendedGcd","doc":"The binary algorithm is generally faster than the Euclidean algorithm for large integers\nbecause it avoids expensive division operations, using only bit shifts and additions.","ref":"BinaryExtendedGcd.html#module-performance"},{"type":"module","title":"Examples - BinaryExtendedGcd","doc":"iex> BinaryExtendedGcd.of(48, 18)\n    {6, 2, -5}\n\n    iex> BinaryExtendedGcd.of(17, 13)\n    {1, -16, 21}\n\n    iex> BinaryExtendedGcd.of(0, 5)\n    {5, 0, 1}\n\n    iex> BinaryExtendedGcd.of(12, 0)\n    {12, 1, 0}","ref":"BinaryExtendedGcd.html#module-examples"},{"type":"function","title":"BinaryExtendedGcd.of/2","doc":"Computes the extended GCD of two integers.\n\nReturns a tuple `{gcd, x, y}` where:\n- `gcd` is the greatest common divisor of `a` and `b`\n- `x` and `y` are Bézout coefficients such that $gcd(a, b) = ax + by$","ref":"BinaryExtendedGcd.html#of/2"},{"type":"function","title":"Parameters - BinaryExtendedGcd.of/2","doc":"- `a` - First integer\n- `b` - Second integer","ref":"BinaryExtendedGcd.html#of/2-parameters"},{"type":"function","title":"Returns - BinaryExtendedGcd.of/2","doc":"`{gcd, x, y}` where:\n- `gcd` is the greatest common divisor of `a` and `b`\n- `x` and `y` are integers satisfying $gcd(a, b) = ax + by$","ref":"BinaryExtendedGcd.html#of/2-returns"},{"type":"function","title":"Examples - BinaryExtendedGcd.of/2","doc":"iex> BinaryExtendedGcd.of(48, 18)\n    {6, 2, -5}\n    # 6 = 48 * 2 + 18 * (-5)\n\n    iex> BinaryExtendedGcd.of(17, 13)\n    {1, -16, 21}\n    # 1 = 17 * (-16) + 13 * 21\n\n    iex> BinaryExtendedGcd.of(0, 5)\n    {5, 0, 1}\n    # When one number is 0, the other is the GCD\n\n    iex> BinaryExtendedGcd.of(12, 0)\n    {12, 1, 0}\n    # When one number is 0, the other is the GCD","ref":"BinaryExtendedGcd.html#of/2-examples"},{"type":"function","title":"Mathematical Properties - BinaryExtendedGcd.of/2","doc":"The result satisfies the following properties:\n- `gcd` divides both `a` and `b`\n- `gcd` is the largest number that divides both `a` and `b`\n- $gcd(a, b) = ax + by$ (Bézout's identity)","ref":"BinaryExtendedGcd.html#of/2-mathematical-properties"},{"type":"extras","title":"BinaryExtendedGcd","doc":"# BinaryExtendedGcd\n\nA fast implementation of the binary extended GCD algorithm for Elixir.\n\nThis library provides an efficient implementation of the extended greatest common divisor (GCD) algorithm using the binary GCD method. The binary algorithm is particularly efficient for large integers as it eliminates expensive division operations by using only bit shifts and additions.","ref":"readme.html"},{"type":"extras","title":"Features - BinaryExtendedGcd","doc":"- **Fast Performance**: Uses binary operations instead of division for better performance on large integers\n- **Extended GCD**: Computes both the GCD and Bézout coefficients\n- **Mathematically Correct**: Implements the binary extended GCD algorithm with proper coefficient tracking\n- **Well Tested**: Includes comprehensive randomized test suite\n- **Documented**: Full documentation with examples and mathematical explanations","ref":"readme.html#features"},{"type":"extras","title":"Installation - BinaryExtendedGcd","doc":"The package can be installed\nby adding `binary_extended_gcd` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:binary_extended_gcd, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - BinaryExtendedGcd","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Basic Usage - BinaryExtendedGcd","doc":"```elixir\n# Compute extended GCD of 48 and 18\n{gcd, x, y} = BinaryExtendedGcd.of(48, 18)\n# Returns {6, -1, 3}\n# This means: 6 = 48 * (-1) + 18 * 3\n\n# Compute extended GCD of 17 and 13\n{gcd, x, y} = BinaryExtendedGcd.of(17, 13)\n# Returns {1, 4, -5}\n# This means: 1 = 17 * 4 + 13 * (-5)\n```","ref":"readme.html#basic-usage"},{"type":"extras","title":"Edge Cases - BinaryExtendedGcd","doc":"```elixir\n# When one number is 0\nBinaryExtendedGcd.of(0, 5)   # Returns {5, 0, 1}\nBinaryExtendedGcd.of(12, 0)  # Returns {12, 1, 0}\n\n# Coprime numbers\nBinaryExtendedGcd.of(17, 13) # Returns {1, 4, -5}\n```","ref":"readme.html#edge-cases"},{"type":"extras","title":"Mathematical Background - BinaryExtendedGcd","doc":"","ref":"readme.html#mathematical-background"},{"type":"extras","title":"Extended GCD - BinaryExtendedGcd","doc":"The extended GCD not only computes the greatest common divisor of two integers `a` and `b`, but also finds Bézout coefficients $x$ and $y$ such that:\n\n$$gcd(a, b) = ax + by$$\n\nThis is known as Bézout's identity and is useful in many applications including:\n- Cryptography (RSA, modular arithmetic)\n- Solving linear Diophantine equations\n- Computing modular multiplicative inverses","ref":"readme.html#extended-gcd"},{"type":"extras","title":"Binary GCD Algorithm - BinaryExtendedGcd","doc":"The binary GCD algorithm is an efficient variant of the Euclidean algorithm that:\n\n1. **Eliminates division**: Uses only bit shifts and additions\n2. **Handles even numbers efficiently**: Divides by 2 using bit shifts\n3. **Maintains Bézout coefficients**: Tracks coefficients throughout the computation\n\nThe algorithm works by:\n1. Extracting common factors of 2 from both numbers\n2. Using bit operations to handle even/odd cases efficiently\n3. Maintaining Bézout coefficients throughout the computation\n4. Restoring the common factors at the end","ref":"readme.html#binary-gcd-algorithm"},{"type":"extras","title":"Performance - BinaryExtendedGcd","doc":"The binary algorithm is generally faster than the Euclidean algorithm for large integers because:\n- Bit shifts are faster than division operations\n- Fewer arithmetic operations are required\n- Better cache locality due to simpler operations","ref":"readme.html#performance"},{"type":"extras","title":"API Reference - BinaryExtendedGcd","doc":"### `BinaryExtendedGcd.of(a, b)`\n\nComputes the extended GCD of two integers.\n\n**Parameters:**\n- `a` - First integer\n- `b` - Second integer\n\n**Returns:**\n`{gcd, x, y}` where:\n- `gcd` is the greatest common divisor of `a` and `b`\n- `x` and `y` are integers satisfying $gcd(a, b) = ax + by$\n\n**Examples:**\n```elixir\niex> BinaryExtendedGcd.of(48, 18)\n{6, 2, -5}\n\niex> BinaryExtendedGcd.of(17, 13)\n{1, -16, 21}\n\niex> BinaryExtendedGcd.of(0, 5)\n{5, 0, 1}\n```","ref":"readme.html#api-reference"},{"type":"extras","title":"Mathematical Properties - BinaryExtendedGcd","doc":"The result satisfies the following properties:\n- `gcd` divides both `a` and `b`\n- `gcd` is the largest number that divides both `a` and `b`\n- $gcd(a, b) = ax + by$ (Bézout's identity)","ref":"readme.html#mathematical-properties"},{"type":"extras","title":"Testing - BinaryExtendedGcd","doc":"The library includes comprehensive tests with 1000 randomized test cases that verify:\n- GCD divides both input numbers\n- No larger number divides both inputs\n- Bézout's identity holds: $gcd = ax + by$\n\nRun tests with:\n```bash\nmix test\n```","ref":"readme.html#testing"},{"type":"extras","title":"Dependencies - BinaryExtendedGcd","doc":"- `common_twos` - For extracting common factors of 2\n- `nstandard` - For code quality and development tools","ref":"readme.html#dependencies"},{"type":"extras","title":"Development - BinaryExtendedGcd","doc":"","ref":"readme.html#development"},{"type":"extras","title":"Building Documentation - BinaryExtendedGcd","doc":"```bash\nmix docs\n```","ref":"readme.html#building-documentation"},{"type":"extras","title":"Code Quality - BinaryExtendedGcd","doc":"```bash\nmix check\n```\n\nThis runs:\n- Credo (code style and quality)\n- Dialyzer (static analysis)\n- Spell checking\n- Format checking","ref":"readme.html#code-quality"},{"type":"extras","title":"License - BinaryExtendedGcd","doc":"This project is licensed under the Apache License 2.0 - see the [LICENSE.md](LICENSE.md) file for details.","ref":"readme.html#license"},{"type":"extras","title":"Contributing - BinaryExtendedGcd","doc":"1. Fork the repository\n2. Create a feature branch\n3. Make your changes\n4. Add tests for new functionality\n5. Run `mix check` to ensure code quality\n6. Submit a pull request","ref":"readme.html#contributing"},{"type":"extras","title":"References - BinaryExtendedGcd","doc":"- [Binary GCD Algorithm](https://en.wikipedia.org/wiki/Binary_GCD_algorithm)\n- [Extended Euclidean Algorithm](https://en.wikipedia.org/wiki/Extended_Euclidean_algorithm)\n- [Bézout's Identity](https://en.wikipedia.org/wiki/B%C3%A9zout%27s_identity)","ref":"readme.html#references"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright [yyyy] [name of copyright owner]\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"- TODO: write changelog","ref":"changelog.html#v0-1-0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}